#property link          "https://www.earnforex.com/metatrader-scripts/close-all-orders/"
#property version       "1.00"
#property strict
#property copyright     "EarnForex.com - 2020-2021"
#property description   "This is a script to close all the open market orders" 
#property description   " "
#property description   "WARNING : You use this software at your own risk."
#property description   "The creator of these plugins cannot be held responsible for any damage or loss."
#property description   " "
#property description   "Find More on EarnForex.com"
#property icon          "\\Files\\EF-Icon-64x64px.ico"
#property show_inputs

enum ENUM_ORDER_TYPES{
   ALL_ORDERS=1,  //ALL ORDERS
   ONLY_BUY=2,    //BUY ONLY
   ONLY_SELL=3    //SELL ONLY
};

input bool OnlyCurrentSymbol=false;   //Close only instrument in the chart
input ENUM_ORDER_TYPES OrderTypeFilter=ALL_ORDERS;     //Type of orders to close
input bool OnlyInProfit=false;        //Close only orders in profit
input bool OnlyInLoss=false;          //Close only orders in loss
input bool OnlyMagicNumber=false;     //Close only orders matching the magic number
input int MagicNumber=0;              //Matching magic number
input bool OnlyWithComment=false;     //Close only orders with the following comment
input string MatchingComment="";      //Matching comment
input int Slippage=2;                 //Slippage
input int Delay=0;                    //Delay to wait between closing orders (in milliseconds)
      

void CloseOrders(){
   
   //Update the exchange rates before closing the orders
   RefreshRates();
      //Log in the terminal the total of orders, current and past
      Print(OrdersTotal());
      
   //Start a loop to scan all the orders
   //The loop starts from the last otherwise it would miss orders
   for(int i=(OrdersTotal()-1);i>=0;i--){
      
      //If the order cannot be selected throw and log an error
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false){
         Print("ERROR - Unable to select the order - ",GetLastError());
         break;
      } 

      //check if the order matches the filter and if not skip the order and move to the next
      if(OrderTypeFilter==ONLY_SELL && OrderType()==OP_BUY) continue;    //don't action if the order it is a buy order and it was selected to only delete sell orders
      if(OrderTypeFilter==ONLY_BUY && OrderType()==OP_SELL) continue;    //don't action if the order it is a sell order and it was selected to only delete buy orders
      if(OnlyCurrentSymbol && OrderSymbol()!=Symbol()) continue;
      if(OnlyInProfit && OrderProfit()<=0) continue;
      if(OnlyInLoss && OrderProfit()>=0) continue;
      if(OnlyMagicNumber && OrderMagicNumber()!=MagicNumber) continue;
      if(OnlyWithComment && StringCompare(OrderComment(),MatchingComment)!=0) continue;
      
      //Create the required variables
      //Result variable, to check if the operation is successful or not
      bool res=false;
      
      //Bid and Ask Price for the Instrument of the order
      double BidPrice=MarketInfo(OrderSymbol(),MODE_BID);
      double AskPrice=MarketInfo(OrderSymbol(),MODE_ASK);

      //Closing the order using the correct price depending on the type of order
      if(OrderType()==OP_BUY){
         res=OrderClose(OrderTicket(),OrderLots(),BidPrice,Slippage);
      }
      if(OrderType()==OP_SELL){
         res=OrderClose(OrderTicket(),OrderLots(),AskPrice,Slippage);
      }
      
      //If there was an error log it
      if(res==false) Print("ERROR - Unable to close the order - ",OrderTicket()," - ",GetLastError());
   
      Sleep(Delay);
   }
}


void OnStart(){

   //Call the function when the script is run
   CloseOrders();

}